@@ -14,14 +14,14 @@
 #  limitations under the License.
 #
 
-from pipeline.component.component_base import Component
+from pipeline.component.component_base import FateComponent
 from pipeline.component.nn.models.sequantial import Sequential
 from pipeline.interface import Input
 from pipeline.interface import Output
 from pipeline.utils.tools import extract_explicit_parameter
 
 
-class HeteroNN(Component):
+class HeteroNN(FateComponent):
 
     @extract_explicit_parameter
     def __init__(self, task_type="classification", epochs=None, batch_size=-1, early_stop="diff",
@@ -35,7 +35,7 @@ class HeteroNN(Component):
         explicit_parameters["top_nn_define"] = None
         explicit_parameters["interactive_layer_define"] = None
         explicit_parameters["config_type"] = "keras"
-        Component.__init__(self, **explicit_parameters)
+        FateComponent.__init__(self, **explicit_parameters)
 
         if "name" in explicit_parameters:
             del explicit_parameters["name"]
