@@ -13,6 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 #
+ALLOW_REVEAL_GUEST_ONLY = True
 
 ARBITER = 'arbiter'
 HOST = 'host'
@@ -39,6 +40,10 @@ L2_PENALTY = 'L2'
 FLOAT_ZERO = 1e-8
 OVERFLOW_THRESHOLD = 1e8
 
+OT_HAUCK = 'OT_Hauck'
+CE_PH = 'CommutativeEncryptionPohligHellman'
+AES = 'aes'
+
 PARAM_MAXDEPTH = 5
 MAX_CLASSNUM = 1000
 MIN_BATCH_SIZE = 10
@@ -49,6 +54,7 @@ HOMO = "homo"
 
 RAW = "raw"
 RSA = "rsa"
+DH = "dh"
 
 # evaluation
 AUC = "auc"
@@ -256,7 +262,12 @@ COL = 'col'
 PHONE = 'phone'
 IMEI = 'imei'
 MD5 = 'md5'
+SHA1 = 'sha1'
+SHA224 = 'sha224'
 SHA256 = 'sha256'
+SHA384 = 'sha384'
+SHA512 = 'sha512'
+SM3 = 'sm3'
 INTERSECT_CACHE_TAG = 'Za'
 
 SHARE_INFO_COL_NAME = "share_info"
@@ -283,6 +294,10 @@ HETERO_SBT = 'hetero_sbt'
 HETERO_FAST_SBT_MIX = 'hetero_fast_sbt_mix'
 HETERO_FAST_SBT_LAYERED = 'hetero_fast_sbt_layered'
 
+# homm sbt backend
+MEMORY_BACKEND = 'memory'
+DISTRIBUTED_BACKEND = 'distributed'
+
 # column_expand
 MANUAL = 'manual'
 
@@ -296,3 +311,9 @@ MAX_SAMPLE_OUTPUT_LIMIT = 10 ** 6
 
 # Hetero NN Selective BP Strategy
 SELECTIVE_SIZE = 1024
+
+# intersect join methods
+INNER_JOIN = "inner_join"
+LEFT_JOIN = "left_join"
+
+DEFAULT_KEY_LENGTH = 1024
